==> nextcloud-php72-19.0.3.txz: usr/local/www/nextcloud/apps-pkg/updatenotification/l10n/mk.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "Достапна е нова верзија {version}. Видете ги информациите како да ја ажурирате.",
    "Channel updated" : "Каналот е ажуриран",
    "Update notifications" : "Известувања за ажурирање",
    "The update server could not be reached since %d days to check for new updates." : "Серверот за ажурирање не е проверен %d дена.",
    "Please check the Nextcloud and server log files for errors." : "Проверете ги записите во Nextcloud и записите во серверот за грешките.",
    "Update to %1$s is available." : "Достапно е аурирање во верзија %1$s.",
    "Update for %1$s to version %2$s is available." : "Достапно е ажурирање од %1$s во верзија %2$s.",
    "Update for {app} to version %s is available." : "Достапно е ажурирање за {app} во верзија %s.",
    "Update notification" : "Известување за ажурирање",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Прикажува известувања за ажурирање на Nextcloud и овозможува SSO за надградувачот.",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "Верзијата која ја користе повеќе не се одржува. Ве молиме што поскоро да ја ажурирајте верзија во понова.",
    "Apps missing updates" : "Недостасуваат ажурирања за апликации",
    "View in store" : "Преглед во продавницата за апликации",
    "Apps with available updates" : "Апликации со достапни ажурирања",
    "Open updater" : "Стартувај го надградувачот",
    "Download now" : "Преземи",
    "What's new?" : "Што е ново",
    "The update check is not yet finished. Please refresh the page." : "Сеуште нема извшено проверка за ажурирање, Ве молиме рефреширајте ја страната.",
    "Your version is up to date." : "Вашата верзија е ажурирана.",
    "A non-default update server is in use to be checked for updates:" : "Нестандарден сервер е поставен за проверка за ажурирање:",
    "Update channel:" : "Канал за ажурирање:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Секогаш можете да ажурирате на нова верзија. Но никогаш нема да можете да се вратите на постара верзија.",
    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "Можно е да треба некое време додека новата верзија се прикаже овде. Ние испорачуваме нови до нашите корисници но од време на време некој верзии ги прескокнуваме поради пројандени проблеми во истите.",
    "Notify members of the following groups about available updates:" : "Извести ги членовите на овие групи за достапните ажурирања:",
    "Only notification for app updates are available." : "Известувања само за достапни ажурирања на апликации.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Избраниот канал за ажурирање ќе овозможи известувања за застарениот сервер.",
    "The selected update channel does not support updates of the server." : "Избраниот канал за ажурирање не поддржува ажурирање за серверот.",
    "A new version is available: <strong>{newVersionString}</strong>" : "Достапна е нова верзија: <strong>{newVersionString}</strong>",
    "Checked on {lastCheckedDate}" : "Проверено на {lastCheckedDate}",
    "Checking apps for compatible updates" : "Проверка за компатибилност на апликациите со новата верзија",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Бидете сигурни дека во config.php датотеката параматарот <samp>appstoreenabled</samp> е поставен на false.",
    "Could not connect to the appstore or the appstore returned no updates at all. Search manually for updates or make sure your server has access to the internet and can connect to the appstore." : "Неможе да се поврзе со appstore или одговорот е дека нема ажурирање. Пребарајте рачно за ажурирање или бидете сигурни дека серверот има пристап до интернет и може да се поврзе со продавницата.",
    "<strong>All</strong> apps have an update for this version available" : "<strong>Сите</strong> апликации имаат ажурирања за оваа верзија",
    "View changelog" : "Видете ги проммените",
    "Enterprise" : "Професионален",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "За професионална употреба. Овозможува секогаш најново ниво на ажурирање, но нема веднаш да се ажурира на следното големо издание. Ова ажурирање се случува откако Nextcloud GmbH ќе направи дополнително тестирање за големи и критични сервери. Овој канал е достапен само за клиентите и го имаат пакетот Nextcloud Enterprise.",
    "Stable" : "Стабилна",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "Најнова стабилна верзија. Корисно за редовна употреба и секогаш ќе се ажурира до последната најнова верзија.",
    "Beta" : "Бета",
    "A pre-release version only for testing new features, not for production environments." : "Неиздадена верзија само за тестирање на новите можности, не е за редовна употреба.",
    "_<strong>%n</strong> app has no update for this version available_::_<strong>%n</strong> apps have no update for this version available_" : ["<strong>%n</strong> апликација нема ажурирање за оваа веријза","<strong>%n</strong> апликации немаат ажурирања за оваа веријза"]
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");

==> nextcloud-php74-20.0.7.txz: usr/local/www/nextcloud/apps-pkg/updatenotification/l10n/mk.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "Достапна е нова верзија {version}. Видете ги информациите како да ја ажурирате.",
    "Channel updated" : "Каналот е ажуриран",
    "Update notifications" : "Известувања за ажурирање",
    "The update server could not be reached since %d days to check for new updates." : "Серверот за ажурирање не е проверен %d дена.",
    "Please check the Nextcloud and server log files for errors." : "Проверете ги записите во Cloud-от и записите во серверот за грешките.",
    "Update to %1$s is available." : "Достапно е аурирање во верзија %1$s.",
    "Update for %1$s to version %2$s is available." : "Достапно е ажурирање од %1$s во верзија %2$s.",
    "Update for {app} to version %s is available." : "Достапно е ажурирање за {app} во верзија %s.",
    "Update notification" : "Известување за ажурирање",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Прикажува известувања за ажурирање на Nextcloud и овозможува SSO за надградувачот.",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "Верзијата која ја користе повеќе не се одржува. Ве молиме што поскоро да ја ажурирајте верзија во понова.",
    "Apps missing updates" : "Недостасуваат ажурирања за апликации",
    "View in store" : "Преглед во продавницата за апликации",
    "Apps with available updates" : "Апликации со достапни ажурирања",
    "Open updater" : "Стартувај го надградувачот",
    "Download now" : "Преземи",
    "What's new?" : "Што е ново",
    "The update check is not yet finished. Please refresh the page." : "Сеуште нема извшено проверка за ажурирање, Ве молиме рефреширајте ја страната.",
    "Your version is up to date." : "Вашата верзија е ажурирана.",
    "A non-default update server is in use to be checked for updates:" : "Нестандарден сервер е поставен за проверка за ажурирање:",
    "Update channel:" : "Канал за ажурирање:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Секогаш можете да ажурирате на нова верзија. Но никогаш нема да можете да се вратите на постара верзија.",
    "Notify members of the following groups about available updates:" : "Извести ги членовите на овие групи за достапните ажурирања:",
    "Only notification for app updates are available." : "Известувања само за достапни ажурирања на апликации.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Избраниот канал за ажурирање ќе овозможи известувања за застарениот сервер.",
    "The selected update channel does not support updates of the server." : "Избраниот канал за ажурирање не поддржува ажурирање за серверот.",
    "A new version is available: <strong>{newVersionString}</strong>" : "Достапна е нова верзија: <strong>{newVersionString}</strong>",
    "Checked on {lastCheckedDate}" : "Проверено на {lastCheckedDate}",
    "Checking apps for compatible updates" : "Проверка за компатибилност на апликациите со новата верзија",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Бидете сигурни дека во config.php датотеката параматарот <samp>appstoreenabled</samp> е поставен на false.",
    "Could not connect to the appstore or the appstore returned no updates at all. Search manually for updates or make sure your server has access to the internet and can connect to the appstore." : "Неможе да се поврзе со appstore или одговорот е дека нема ажурирање. Пребарајте рачно за ажурирање или бидете сигурни дека серверот има пристап до интернет и може да се поврзе со продавницата.",
    "<strong>All</strong> apps have an update for this version available" : "<strong>Сите</strong> апликации имаат ажурирања за оваа верзија",
    "View changelog" : "Видете ги проммените",
    "Enterprise" : "Професионален",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "За професионална употреба. Овозможува секогаш најново ниво на ажурирање, но нема веднаш да се ажурира на следното големо издание. Ова ажурирање се случува откако Nextcloud GmbH ќе направи дополнително тестирање за големи и критични сервери. Овој канал е достапен само за клиентите и го имаат пакетот Nextcloud Enterprise.",
    "Stable" : "Стабилна",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "Најнова стабилна верзија. Корисно за редовна употреба и секогаш ќе се ажурира до последната најнова верзија.",
    "Beta" : "Бета",
    "A pre-release version only for testing new features, not for production environments." : "Неиздадена верзија само за тестирање на новите можности, не е за редовна употреба.",
    "_<strong>%n</strong> app has no update for this version available_::_<strong>%n</strong> apps have no update for this version available_" : ["<strong>%n</strong> апликација нема ажурирање за оваа веријза","<strong>%n</strong> апликации немаат ажурирања за оваа веријза"],
    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "Можно е да треба некое време додека новата верзија се прикаже овде. Ние испорачуваме нови до нашите корисници но од време на време некој верзии ги прескокнуваме поради пројандени проблеми во истите."
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
